@@ -40,6 +40,10 @@ class InformationModel(Resource):
         "_modelelements",
         "_informationmodelidentifier",
         "_licensedocument",
+        "_replaces",
+        "_is_replaced_by",
+        "_has_part",
+        "_is_part_of",
     )
 
     _title: dict
@@ -48,6 +52,10 @@ class InformationModel(Resource):
     _modelelements: List[ModelElement]
     _informationmodelidentifier: str
     _licensedocument: LicenseDocument
+    _replaces: List[InformationModel]
+    _is_replaced_by: List[InformationModel]
+    _has_part: List[InformationModel]
+    _is_part_of: List[InformationModel]
 
     def __init__(self) -> None:
         """Inits InformationModel object with default values."""
@@ -55,6 +63,10 @@ class InformationModel(Resource):
         self._type = MODELLDCATNO.InformationModel
         self._subject = []
         self._modelelements = []
+        self._replaces = []
+        self._is_replaced_by = []
+        self._has_part = []
+        self._is_part_of = []
 
     @property
     def informationmodelidentifier(self) -> str:
@@ -143,6 +155,48 @@ class InformationModel(Resource):
         """Set for modelelements."""
         self._modelelements = modelelements
 
+    @property
+    def replaces(self: InformationModel) -> List[InformationModel]:
+        """Get for replaces."""
+        return self._replaces
+
+    @replaces.setter
+    def replaces(self: InformationModel, replaces: List[InformationModel]) -> None:
+        """Set for replaces."""
+        self._replaces = replaces
+
+    @property
+    def is_replaced_by(self: InformationModel) -> List[InformationModel]:
+        """Get for is_replaced_by."""
+        return self._is_replaced_by
+
+    @is_replaced_by.setter
+    def is_replaced_by(
+        self: InformationModel, is_replaced_by: List[InformationModel]
+    ) -> None:
+        """Set for is_replaced_by."""
+        self._is_replaced_by = is_replaced_by
+
+    @property
+    def has_part(self: InformationModel) -> List[InformationModel]:
+        """Get for has_part."""
+        return self._has_part
+
+    @has_part.setter
+    def has_part(self: InformationModel, has_part: List[InformationModel]) -> None:
+        """Set for has_part."""
+        self._has_part = has_part
+
+    @property
+    def is_part_of(self: InformationModel) -> List[InformationModel]:
+        """Get for is_part_of."""
+        return self._is_part_of
+
+    @is_part_of.setter
+    def is_part_of(self: InformationModel, is_part_of: List[InformationModel]) -> None:
+        """Set for is_part_of."""
+        self._is_part_of = is_part_of
+
     def to_rdf(
         self: InformationModel,
         format: str = "turtle",
@@ -176,6 +230,10 @@ class InformationModel(Resource):
         self._subject_to_graph()
         self._modelelements_to_graph()
         self._licensedocument_to_graph()
+        self._replaces_to_graph()
+        self._is_replaced_by_to_graph()
+        self._has_part_to_graph()
+        self._is_part_of_to_graph()
 
         if getattr(self, "informationmodelidentifier", None):
             self._g.add(
@@ -227,7 +285,7 @@ class InformationModel(Resource):
                 self._g.add(
                     (
                         URIRef(self.identifier),
-                        MODELLDCATNO.containsModelelement,
+                        MODELLDCATNO.containsModelElement,
                         _modelelement,
                     )
                 )
@@ -253,6 +311,78 @@ class InformationModel(Resource):
 
             self._g.add((URIRef(self.identifier), DCT.license, _licensedocument))
 
+    def _replaces_to_graph(self: InformationModel) -> None:
+        if getattr(self, "replaces", None):
+
+            for replaces in self._replaces:
+
+                _replaces = URIRef(replaces.identifier)
+
+                for _s, p, o in replaces._to_graph().triples((None, None, None)):
+                    self._g.add((_replaces, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCT.replaces,
+                        _replaces,
+                    )
+                )
+
+    def _is_replaced_by_to_graph(self: InformationModel) -> None:
+        if getattr(self, "is_replaced_by", None):
+
+            for is_replaced_by in self._is_replaced_by:
+
+                _is_replaced_by = URIRef(is_replaced_by.identifier)
+
+                for _s, p, o in is_replaced_by._to_graph().triples((None, None, None)):
+                    self._g.add((_is_replaced_by, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCT.isReplacedBy,
+                        _is_replaced_by,
+                    )
+                )
+
+    def _has_part_to_graph(self: InformationModel) -> None:
+        if getattr(self, "has_part", None):
+
+            for has_part in self._has_part:
+
+                _has_part = URIRef(has_part.identifier)
+
+                for _s, p, o in has_part._to_graph().triples((None, None, None)):
+                    self._g.add((_has_part, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCT.hasPart,
+                        _has_part,
+                    )
+                )
+
+    def _is_part_of_to_graph(self: InformationModel) -> None:
+        if getattr(self, "is_part_of", None):
+
+            for is_part_of in self._is_part_of:
+
+                _is_part_of = URIRef(is_part_of.identifier)
+
+                for _s, p, o in is_part_of._to_graph().triples((None, None, None)):
+                    self._g.add((_is_part_of, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCT.isPartOf,
+                        _is_part_of,
+                    )
+                )
+
 
 class ModelElement(ABC):
     """A class representing a modelldcatno:ModelElement."""
@@ -1812,6 +1942,14 @@ class CodeElement:
         "_top_concept_of",
         "_altlabel",
         "_definition",
+        "_example",
+        "_hiddenlabel",
+        "_note",
+        "_scopenote",
+        "_exclusion_note",
+        "_inclusion_note",
+        "_next_element",
+        "_previous_element",
     )
 
     _identifier: URI
@@ -1825,6 +1963,14 @@ class CodeElement:
     _top_concept_of: List[CodeList]
     _altlabel: dict
     _definition: dict
+    _example: List[str]
+    _hiddenlabel: dict
+    _note: dict
+    _scopenote: dict
+    _exclusion_note: dict
+    _inclusion_note: dict
+    _next_element: CodeElement
+    _previous_element: CodeElement
 
     def __init__(self) -> None:
         """Inits an object with default values."""
@@ -1920,6 +2066,86 @@ class CodeElement:
         """Set for definition."""
         self._definition = definition
 
+    @property
+    def example(self: CodeElement) -> List[str]:
+        """Get for example."""
+        return self._example
+
+    @example.setter
+    def example(self: CodeElement, example: List[str]) -> None:
+        """Set for example."""
+        self._example = example
+
+    @property
+    def hiddenlabel(self: CodeElement) -> dict:
+        """Get for hiddenlabel."""
+        return self._hiddenlabel
+
+    @hiddenlabel.setter
+    def hiddenlabel(self: CodeElement, hiddenlabel: dict) -> None:
+        """Set for hiddenlabel."""
+        self._hiddenlabel = hiddenlabel
+
+    @property
+    def note(self: CodeElement) -> dict:
+        """Get for note."""
+        return self._note
+
+    @note.setter
+    def note(self: CodeElement, note: dict) -> None:
+        """Set for note."""
+        self._note = note
+
+    @property
+    def scopenote(self: CodeElement) -> dict:
+        """Get for scopenote."""
+        return self._scopenote
+
+    @scopenote.setter
+    def scopenote(self: CodeElement, scopenote: dict) -> None:
+        """Set for scopenote."""
+        self._scopenote = scopenote
+
+    @property
+    def exclusion_note(self: CodeElement) -> dict:
+        """Get for exclusion_note."""
+        return self._exclusion_note
+
+    @exclusion_note.setter
+    def exclusion_note(self: CodeElement, exclusion_note: dict) -> None:
+        """Set for exclusion_note."""
+        self._exclusion_note = exclusion_note
+
+    @property
+    def inclusion_note(self: CodeElement) -> dict:
+        """Get for inclusion_note."""
+        return self._inclusion_note
+
+    @inclusion_note.setter
+    def inclusion_note(self: CodeElement, inclusion_note: dict) -> None:
+        """Set for inclusion_note."""
+        self._inclusion_note = inclusion_note
+
+    @property
+    def next_element(self: CodeElement) -> CodeElement:
+        """Get for next_element."""
+        return self._next_element
+
+    @next_element.setter
+    def next_element(self: CodeElement, next_element: CodeElement) -> None:
+        """Set for next_element."""
+        self._next_element = next_element
+
+    @property
+    def previous_element(self: CodeElement) -> CodeElement:
+        """Get for previous_element."""
+        return self._previous_element
+
+    @previous_element.setter
+    def previous_element(self: CodeElement, previous_element: CodeElement) -> None:
+        """Set for previous_element."""
+        self._previous_element = previous_element
+
     def to_rdf(
         self: CodeElement, format: str = "turtle", encoding: Optional[str] = "utf-8"
     ) -> str:
@@ -1964,6 +2190,14 @@ class CodeElement:
         self._top_concept_of_to_graph(_self)
         self._altlabel_to_graph(_self)
         self._definition_to_graph(_self)
+        self._example_to_graph(_self)
+        self._hiddenlabel_to_graph(_self)
+        self._note_to_graph(_self)
+        self._scopenote_to_graph(_self)
+        self._exclusion_note_to_graph(_self)
+        self._inclusion_note_to_graph(_self)
+        self._next_element_to_graph(_self)
+        self._previous_element_to_graph(_self)
 
         return self._g
 
@@ -2056,3 +2290,111 @@ class CodeElement:
                         Literal(self.definition[key], lang=key),
                     )
                 )
+
+    def _example_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "example", None):
+
+            for example in self.example:
+                self._g.add((_self, SKOS.example, Literal(example)))
+
+    def _hiddenlabel_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "hiddenlabel", None):
+
+            for key in self.hiddenlabel:
+                self._g.add(
+                    (
+                        _self,
+                        SKOS.hiddenLabel,
+                        Literal(self.hiddenlabel[key], lang=key),
+                    )
+                )
+
+    def _note_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "note", None):
+
+            for key in self.note:
+                self._g.add(
+                    (
+                        _self,
+                        SKOS.note,
+                        Literal(self.note[key], lang=key),
+                    )
+                )
+
+    def _scopenote_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "scopenote", None):
+
+            for key in self.scopenote:
+                self._g.add(
+                    (
+                        _self,
+                        SKOS.scopeNote,
+                        Literal(self.scopenote[key], lang=key),
+                    )
+                )
+
+    def _exclusion_note_to_graph(self, _self: Any) -> None:
+        if getattr(self, "exclusion_note", None):
+
+            for key in self.exclusion_note:
+                self._g.add(
+                    (
+                        _self,
+                        XKOS.exclusionNote,
+                        Literal(self.exclusion_note[key], lang=key),
+                    )
+                )
+
+    def _inclusion_note_to_graph(self, _self: Any) -> None:
+        if getattr(self, "inclusion_note", None):
+
+            for key in self.inclusion_note:
+                self._g.add(
+                    (
+                        _self,
+                        XKOS.inclusionNote,
+                        Literal(self.inclusion_note[key], lang=key),
+                    )
+                )
+
+    def _next_element_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "next_element", None):
+
+            if getattr(self.next_element, "identifier", None):
+                _next_element = URIRef(self.next_element.identifier)
+            else:
+                _next_element = BNode()
+
+            for _s, p, o in self.next_element._to_graph().triples((None, None, None)):
+                self._g.add(
+                    (_next_element, p, o)
+                    if isinstance(_next_element, BNode)
+                    else (_s, p, o)
+                )
+
+            self._g.add((_self, XKOS.next, _next_element))
+
+    def _previous_element_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "previous_element", None):
+
+            if getattr(self.previous_element, "identifier", None):
+                _previous_element = URIRef(self.previous_element.identifier)
+            else:
+                _previous_element = BNode()
+
+            for _s, p, o in self.previous_element._to_graph().triples(
+                (None, None, None)
+            ):
+                self._g.add(
+                    (_previous_element, p, o)
+                    if isinstance(_previous_element, BNode)
+                    else (_s, p, o)
+                )
+
+            self._g.add((_self, XKOS.previous, _previous_element))
